corr_plus: Correlation

Description Usage Arguments Value Examples

View source: R/corr_plus.R

Description

'corr_plus' function calculates the Pearson correlation coefficient between two variables using complete case analysis that excludes all observations that have NA for at least one variable.

Usage

1
corr_plus(x, y)

Arguments

x

a numeric vector

y

a numeric vector

Value

the value of Pearson correlation coefficient value of the input data

Examples

1
corr_plus(c(1,2,3,4,5), c(1,2,3,NA,5))

UBC-MDS/CorrR documentation built on May 30, 2019, 2:04 a.m.