Description Usage Arguments Value Examples
'corr_plus' function calculates the Pearson correlation coefficient between two variables using complete case analysis that excludes all observations that have NA for at least one variable.
1 | corr_plus(x, y)
|
x |
a numeric vector |
y |
a numeric vector |
the value of Pearson correlation coefficient value of the input data
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.